@@ -1,7 +1,8 @@
 import logging
 import os
-from urllib.parse import urljoin
+import urllib.parse as urlparse
 
+import pkg_resources
 from requests import Response, Session
 
 from .exceptions import Unauthorized
@@ -18,7 +19,7 @@ class TorqueClient(object):
     def __init__(
         self,
         torque_host_prefix: str = "https://",
-        torque_host: str = "qtorque.io",
+        torque_host: str = "portal.qtorque.io",
         space: str = None,
         token: str = None,
         account: str = None,
@@ -30,10 +31,7 @@ class TorqueClient(object):
         if os.environ.get("TORQUE_HOSTNAME"):
             torque_host = os.environ["TORQUE_HOSTNAME"]
 
-        if account:
-            self.base_url = urljoin(f"{torque_host_prefix}{account}.{torque_host}", self.API_URL)
-        else:
-            self.base_url = urljoin(f"{torque_host_prefix}{torque_host}", self.API_URL)
+        self.base_url = urlparse.urljoin(f"{torque_host_prefix}{torque_host}", self.API_URL)
 
         self.session = session
         self.space = space
@@ -63,7 +61,7 @@ class TorqueClient(object):
         password: str,
         session: Session = TorqueSession(),
     ):
-        path = urljoin(self.base_url, f"accounts/{account}/login")
+        path = urlparse.urljoin(self.base_url, f"accounts/{account}/login")
         payload = {"email": email, "password": password}
         resp = session.post(url=path, json=payload)
         if resp.status_code != 200:
@@ -73,11 +71,13 @@ class TorqueClient(object):
         return resp.json().get("access_token", "")
 
     def longtoken(self):
-        url_longtoken = urljoin(self.base_url, "token/longtoken")
+        url_longtoken = urlparse.urljoin(self.base_url, "token/longtoken")
         longtoken_resp = self.session.post(url_longtoken)
         return longtoken_resp.json().get("access_token", "")
 
-    def request(self, endpoint: str, method: str = "GET", params: dict = None, headers: dict = None) -> Response:
+    def request(
+        self, endpoint: str, method: str = "GET", params: dict = None, headers: dict = None, query_params: dict = None
+    ) -> Response:
         """Gets response as Json"""
         method = method.upper()
 
@@ -87,18 +87,28 @@ class TorqueClient(object):
         if headers:
             self.session.headers.update(headers)
 
+        version = pkg_resources.get_distribution("torque-cli").version
+        if version:
+            self.session.headers.update({"User-Agent": f"Torque-CLI/{version}"})
+
         if method in ("POST", "PUT", "DELETE"):
             self.session.headers.update({"Content-Type": "application/json"})
 
         if params is None:
             params = {}
 
-        url = urljoin(self.base_url, endpoint)
+        url = urlparse.urljoin(self.base_url, endpoint)
+
+        if query_params:
+            url_parts = list(urlparse.urlparse(url))
+            url_parts[4] = urlparse.urlencode(query_params)
+            url = urlparse.urlunparse(url_parts)
 
         request_args = {
             "method": method,
             "url": url,
         }
+
         if method == "GET":
             request_args["params"] = params
         else:
