@@ -14,28 +14,27 @@ class BlueprintsCommand(BaseCommand):
     """
     usage:
         torque (bp | blueprint) list [--output=json | --output=json --detail]
-        torque (bp | blueprint) validate <name> [--branch <branch>] [--commit <commitId>] [--output=json]
+        torque (bp | blueprint) get <name> [--source=<source_type>] [--output=json | --output=json --detail]
         torque (bp | blueprint) [--help]
 
     options:
-       -b --branch <branch>     Specify the name of the remote git branch. If not provided, the CLI will attempt to
-                                automatically detect the current working branch. The latest branch commit will be used
-                                by default unless the commit parameter is also specified.
+       -o --output=json           Yield output in JSON format
 
-       -c --commit <commitId>   Specify the commit ID. This can be used to validate a blueprint from an historic commit.
-                                This option can be used together with the branch parameter.
+       -s --source=<source_type>  Specify a type of blueprint source: 'torque' or 'git'. [default: git]
 
-       -o --output=json         Yield output in JSON format
+       -d --detail                Obtain full blueprint data in JSON format
 
-       -d --detail              Obtain full blueprint data in JSON format
-
-       -h --help                Show this message
+       -h --help                  Show this message
     """
 
     RESOURCE_MANAGER = BlueprintsManager
 
     def get_actions_table(self) -> dict:
-        return {"list": self.do_list, "validate": self.do_validate}
+        return {
+            "list": self.do_list,
+            # "validate": self.do_validate,
+            "get": self.do_get,
+        }
 
     def do_list(self) -> (bool, Any):
         detail = self.input_parser.blueprint_list.detail
@@ -50,6 +49,22 @@ class BlueprintsCommand(BaseCommand):
 
         return True, blueprint_list
 
+    def do_get(self) -> (bool, Any):
+        detail = self.input_parser.blueprint_get.detail
+        blueprint_name = self.input_parser.blueprint_get.blueprint_name
+        source = self.input_parser.blueprint_get.source
+
+        try:
+            if detail:
+                bp = self.manager.get_detailed(blueprint_name, source)
+            else:
+                bp = self.manager.get(blueprint_name, source)
+        except Exception as e:
+            logger.exception(e, exc_info=False)
+            return self.die(f"Unable to get details of blueprint '{blueprint_name}'")
+
+        return True, bp
+
     def do_validate(self) -> (bool, Any):
         blueprint_name = self.input_parser.blueprint_validate.blueprint_name
         branch = self.input_parser.blueprint_validate.branch
