@@ -1,7 +1,11 @@
 from abc import ABC
 from typing import Dict
 
-from torque.parsers.command_input_validators import SandboxListValidator, SandboxStartInputValidator
+from torque.parsers.command_input_validators import (
+    BlueprintInputValidator,
+    SandboxListValidator,
+    SandboxStartInputValidator,
+)
 from torque.utils import parse_comma_separated_string
 
 
@@ -17,6 +21,7 @@ class CommandInputParser:
         self.sandbox_status = SandboxStatusInputParser(command_args)
         self.blueprint_list = BlueprintListInputParser(command_args)
         self.blueprint_validate = BlueprintValidateInputParser(command_args)
+        self.blueprint_get = BlueprintGetInputParser(command_args)
         self.configure_set = ConfigureSetInputParser(command_args)
         self.configure_remove = ConfigureRemoveInputParser(command_args)
 
@@ -68,6 +73,18 @@ class BlueprintListInputParser(InputParserBase):
         return self._args.get("--detail")
 
 
+class BlueprintGetInputParser(BlueprintListInputParser):
+    @property
+    def blueprint_name(self) -> bool:
+        return self._args.get("<name>")
+
+    @property
+    def source(self) -> str:
+        source = self._args.get("--source")
+        BlueprintInputValidator.validate_source(source)
+        return source
+
+
 class BlueprintValidateInputParser(InputParserBase):
     @property
     def blueprint_name(self) -> str:
@@ -154,5 +171,6 @@ class SandboxStartInputParser(InputParserBase):
         return parse_comma_separated_string(self._args["--inputs"])
 
     @property
-    def artifacts(self) -> dict:
-        return parse_comma_separated_string(self._args["--artifacts"])
+    def source(self) -> dict:
+        SandboxStartInputValidator.validate_source(self._args)
+        return self._args["--source"]
