@@ -15,12 +15,20 @@ class Sandbox(Resource):
     @classmethod
     def json_deserialize(cls, manager: ResourceManager, json_obj: dict):
         try:
-            sb = Sandbox(manager, json_obj["id"], json_obj["name"], json_obj["blueprint_name"])
+            sandbox_id = json_obj.get("id", None) or json_obj["details"]["id"]
+            sb_details = json_obj["details"]["definition"]
+            sb = Sandbox(
+                manager,
+                sandbox_id,
+                sb_details["metadata"]["name"],
+                sb_details["metadata"]["blueprint_name"],
+            )
+            sb.sandbox_status = json_obj["details"]["computed_status"]
         except KeyError as e:
             raise NotImplementedError(f"unable to create object. Missing keys in Json. Details: {e}")
 
-        for attr in ["description", "errors", "sandbox_status", "launching_progress"]:
-            sb.__dict__[attr] = json_obj.get(attr, "")
+        # for attr in ["description", "errors", "sandbox_status", "launching_progress"]:
+        #     sb.__dict__[attr] = json_obj.get(attr, "")
         # TODO(ddovbii): set all needed attributes
         # sb.errors = json_obj.get("errors", [])
         # sb.description = json_obj.get("description", "")
@@ -42,21 +50,18 @@ class Sandbox(Resource):
 
 class SandboxesManager(ResourceManager):
     resource_obj = Sandbox
-    SANDBOXES_PATH = "sandbox"
-    SPECIFIC_SANDBOX_PATH = "sandboxes"
+    SANDBOXES_PATH = "environments"
+    SANDBOXES_LINK = "sandboxes"
+
+    # SPECIFIC_SANDBOX_PATH = "sandboxes"
 
     def get_sandbox_url(self, sandbox_id: str) -> str:
-        return self._get_full_url(f"{self.SPECIFIC_SANDBOX_PATH}/{sandbox_id}")
+        return self._get_full_url(f"{self.SANDBOXES_PATH}/{sandbox_id}")
 
     def get_sandbox_ui_link(self, sandbox_id: str) -> str:
         url = urlparse(self.get_sandbox_url(sandbox_id))
         space = url.path.split("/")[3]
-        if self.client.account:
-            ui_url = f"https://{url.hostname}/{space}/{self.SPECIFIC_SANDBOX_PATH}/{sandbox_id}"
-        else:
-            ui_url = f"https://[YOUR_ACCOUNT].{url.hostname}/{space}/{self.SPECIFIC_SANDBOX_PATH}/{sandbox_id}"
-
-        return ui_url
+        return f"https://{url.hostname}/{space}/{self.SANDBOXES_LINK}/{sandbox_id}"
 
     def get(self, sandbox_id: str) -> Sandbox:
         url = f"{self.SANDBOXES_PATH}/{sandbox_id}"
@@ -84,11 +89,16 @@ class SandboxesManager(ResourceManager):
         duration: int = 120,
         branch: str = None,
         commit: str = None,
-        artifacts: dict = None,
         inputs: dict = None,
+        source: str = None,
     ) -> str:
         url = "sandbox"
 
+        source_type_map = {
+            "git": "git_repository",
+            "torque": "qtorque",
+        }
+
         if commit and not branch:
             raise ValueError("Commit is passed without branch")
 
@@ -96,10 +106,12 @@ class SandboxesManager(ResourceManager):
 
         params = {
             "sandbox_name": sandbox_name,
-            "blueprint_name": blueprint_name,
             "duration": iso_duration,
             "inputs": inputs,
-            "artifacts": artifacts,
+            "source": {
+                "blueprint_source_type": source_type_map.get(source, None),
+                "blueprint_name": blueprint_name,
+            },
         }
 
         if branch:
